@@ -7,6 +7,7 @@
 
 #include "channelfactory.h"
 
+#include <QQmlEngine>
 #include <QUrl>
 
 class Channel;
@@ -14,6 +15,7 @@ class Channel;
 class ChannelsModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_PROPERTY(bool onlyFavorites READ onlyFavorites WRITE setOnlyFavorites)
 
 public:
@@ -23,7 +25,7 @@ public:
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QHash<int, QByteArray> roleNames() const override;
     int rowCount(const QModelIndex &parent) const override;
-    Q_INVOKABLE void setFavorite(const QString &channelId, bool favorite);
+    Q_INVOKABLE void setFavorite(const ChannelId &channelId, bool favorite);
     Q_INVOKABLE void move(int from, int to);
     Q_INVOKABLE void save();
 
